Tuples
::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   tuplesareimmutable.rst
   comparingtuples.rst
   tupleassignment.rst
   dictionariesandtuples.rst
   multipleassignments.rst
   mostcommonword.rst
   usingtuplesaskeys.rst
   sequences.rst
   debugging.rst
   glossary.rst
   Exercises.rst
   mixedupcode.rst
   writecode.rst
